.. pyflowline documentation master file, created by
   sphinx-quickstart on Sun Jan 15 01:20:02 2023.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to pyflowline's documentation!
======================================

.. toctree::
   :maxdepth: 3
   :numbered:
   
   readme
   quickstart
   installation/installation   
   data/data
   algorithm/algorithm
   application/application
   visualization
   references
   history
   authors
   support
   contribution
   faq
   api/api   
   

Addendum
--------

.. toctree::
   :maxdepth: 3

   glossary

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
